#!/bin/bash

PROGNAME=${0##*/}

_SSI_HEAD="<!--"
_SSI_TAIL="-->"
_SBEGIN=" section begin$_SSI_TAIL"
_SEND=" section end$_SSI_TAIL"
_OPT_SECTION="$_SSI_HEADOptional link section end$_SSI_TAIL"

function usage()
{
  echo -e "Usage: $PROGNAME [options] add|rm title [text]" 1>&2
  echo -e "add | remove section title and text to home page" 1>&2
}

function add_section() {
  [ $# -eq 2 ] || abort "$FUNCNAME: usage $FUNCNAME FILE TEXT"
  [ -r $1 ] || abort "Cannot read file $1"
  local tmpfile=/tmp/$PROGNAME.$$
  local retcode

  awk -f - << 'EOF' "text=$2" "opt_section=$_OPT_SECTION" "$1" > $tmpfile
BEGIN {
  found=0;
}
($0 ~ opt_section){
  print text;
  print $0;
  found=1;
	next;
}
{ print }
END {
  if (!found)
    print text;
}
EOF
  retcode=$?
  mv -f $tmpfile $1
  return $retcode
}

function rm_section() {
  [ $# -eq 2 ] || abort "$FUNCNAME: usage $FUNCNAME FILE TITLE"
  [ -r $1 ] || abort "Cannot read file $1"
  local tmpfile=/tmp/$PROGNAME.$$
  local retcode

  awk -f - << 'EOF' "title=$2" "ssi_head=$_SSI_HEAD"\
    "sbegin=$_SBEGIN" "send=$_SEND" "$1" > $tmpfile
BEGIN {
  prn=1;
}

($0 ~ ssi_head title sbegin){
  prn=0;
	next;
}

($0 ~ ssi_head title send){
  prn=1;
	next;
}

{ 
  if ( prn )
    print 
}
EOF
  retcode=$?
  mv -f $tmpfile $1
  return $?
}

if [ $# -lt 2 ]; then
  usage
  exit 1
fi

MODE=$1
if [ $MODE != "add" -a $MODE != "rm" ]; then
  usage
  exit 1
fi
FILE="/var/www/html/hspc-wwwroot.html"
if [ ! -r $FILE ]; then
  echo "File $FILE not exist or unreadable."
  exit 1
fi
PACKET=$2

case "$MODE" in
  add) 
    shift 2
    for i; do
      add_section $FILE \
        "$_SSI_HEAD$PACKET$_SBEGIN\n$i\n$_SSI_HEAD$PACKET$_SEND"
    done
    ;;
  rm)
    rm_section $FILE $PACKET
    ;;
  *) usage ; exit 1 ;;
esac
exit $?

